==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ComponentRouteSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ComponentRouteSpecFluentImpl<A extends ComponentRouteSpecFluent<A>> extends BaseFluent<A> implements ComponentRouteSpecFluent<A>{
  public ComponentRouteSpecFluentImpl() {
  }
  public ComponentRouteSpecFluentImpl(ComponentRouteSpec instance) {
    this.withHostname(instance.getHostname()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withServingCertKeyPairSecret(instance.getServingCertKeyPairSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String hostname;
  private String name;
  private String namespace;
  private SecretNameReferenceBuilder servingCertKeyPairSecret;
  private Map<String,Object> additionalProperties;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertKeyPairSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null ?this.servingCertKeyPairSecret.build():null;
  }
  public SecretNameReference buildServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null ?this.servingCertKeyPairSecret.build():null;
  }
  public A withServingCertKeyPairSecret(SecretNameReference servingCertKeyPairSecret) {
    _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret);
    if (servingCertKeyPairSecret!=null){ this.servingCertKeyPairSecret= new SecretNameReferenceBuilder(servingCertKeyPairSecret); _visitables.get("servingCertKeyPairSecret").add(this.servingCertKeyPairSecret);} else { this.servingCertKeyPairSecret = null; _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret); } return (A) this;
  }
  public Boolean hasServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret != null;
  }
  public A withNewServingCertKeyPairSecret(String name) {
    return (A)withServingCertKeyPairSecret(new SecretNameReference(name));
  }
  public ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecret() {
    return new ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl();
  }
  public ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecretLike(SecretNameReference item) {
    return new ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl(item);
  }
  public ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret());
  }
  public ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): new SecretNameReferenceBuilder().build());
  }
  public ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecretLike(SecretNameReference item) {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ComponentRouteSpecFluentImpl that = (ComponentRouteSpecFluentImpl) o;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (servingCertKeyPairSecret != null ? !servingCertKeyPairSecret.equals(that.servingCertKeyPairSecret) :that.servingCertKeyPairSecret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  name,  namespace,  servingCertKeyPairSecret,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (servingCertKeyPairSecret != null) { sb.append("servingCertKeyPairSecret:"); sb.append(servingCertKeyPairSecret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServingCertKeyPairSecretNestedImpl<N> extends SecretNameReferenceFluentImpl<ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>> implements ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>,Nested<N>{
    ServingCertKeyPairSecretNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ServingCertKeyPairSecretNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ComponentRouteSpecFluentImpl.this.withServingCertKeyPairSecret(builder.build());
    }
    public N endServingCertKeyPairSecret() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ComponentRouteSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ComponentRouteSpecFluentImpl<A extends ComponentRouteSpecFluent<A>> extends BaseFluent<A> implements ComponentRouteSpecFluent<A>{
  public ComponentRouteSpecFluentImpl() {
  }
  public ComponentRouteSpecFluentImpl(ComponentRouteSpec instance) {
    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withServingCertKeyPairSecret(instance.getServingCertKeyPairSecret());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String hostname;
  private String name;
  private String namespace;
  private SecretNameReferenceBuilder servingCertKeyPairSecret;
  private Map<String,Object> additionalProperties;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertKeyPairSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null ?this.servingCertKeyPairSecret.build():null;
  }
  public SecretNameReference buildServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null ?this.servingCertKeyPairSecret.build():null;
  }
  public A withServingCertKeyPairSecret(SecretNameReference servingCertKeyPairSecret) {
    _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret);
    if (servingCertKeyPairSecret!=null){ this.servingCertKeyPairSecret= new SecretNameReferenceBuilder(servingCertKeyPairSecret); _visitables.get("servingCertKeyPairSecret").add(this.servingCertKeyPairSecret);} else { this.servingCertKeyPairSecret = null; _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret); } return (A) this;
  }
  public Boolean hasServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret != null;
  }
  public A withNewServingCertKeyPairSecret(String name) {
    return (A)withServingCertKeyPairSecret(new SecretNameReference(name));
  }
  public ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecret() {
    return new ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl();
  }
  public ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecretLike(SecretNameReference item) {
    return new ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl(item);
  }
  public ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<A> editServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret());
  }
  public ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): new SecretNameReferenceBuilder().build());
  }
  public ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecretLike(SecretNameReference item) {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComponentRouteSpecFluentImpl that = (ComponentRouteSpecFluentImpl) o;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(servingCertKeyPairSecret, that.servingCertKeyPairSecret)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  name,  namespace,  servingCertKeyPairSecret,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (servingCertKeyPairSecret != null) { sb.append("servingCertKeyPairSecret:"); sb.append(servingCertKeyPairSecret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServingCertKeyPairSecretNestedImpl<N> extends SecretNameReferenceFluentImpl<ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<N>> implements ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNested<N>,Nested<N>{
    ServingCertKeyPairSecretNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ServingCertKeyPairSecretNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ComponentRouteSpecFluentImpl.this.withServingCertKeyPairSecret(builder.build());
    }
    public N endServingCertKeyPairSecret() {
      return and();
    }
    
  }
  
}
